#!/bin/sh
#
# This script is responsible for installing the Comtrol Rocketport driver
#

if [ `whoami` != root ]; then
	echo "You must be root to install the device driver!"
	exit 1
fi

#
# Check to see whether or not mod_rocket.o was built; if it wasn't built,
# we don't need to install it.
#
if [ -f mod_rocket.o ]; then
	OBJS="mod_rocket.o rocket.o"
else
	OBJS=rocket.o
fi

# Install a copy of the driver in the version independent location
if [ ! -d /lib/modules ]; then 
	mkdir -p /lib/modules
fi

cp $OBJS /lib/modules

# Install a copy of the driver in a kernel version specific location
KVER=`grep UTS_RELEASE /usr/include/linux/version.h | \
	awk '{print $3}' | tr -d \"`

if [ ! -d /lib/modules/$KVER/misc ]; then 
	mkdir -p /lib/modules/$KVER/misc
fi

cp $OBJS /lib/modules

#
# OK, now we install the installation script 
#
if [ -d /etc/rc.d/init.d ]; then 
	# This is a RedHat or other system using a System V init scheme
	if [ ! -f /etc/rc.d/init.d/rc.rocket ]; then
		echo "You are using a system which uses the System V init"
		echo "scheme.  The initialization script has been installed"
		echo "in /etc/rc.d/init.d and it has been automatically "
		echo "set up to be run when you reboot"

		cp rc.rocket /etc/rc.d/init.d
		ln -sf ../init.d/rc.rocket /etc/rc.d/rc2.d/S83rc.rocket
		ln -sf ../init.d/rc.rocket /etc/rc.d/rc3.d/S83rc.rocket
		ln -sf ../init.d/rc.rocket /etc/rc.d/rc5.d/S83rc.rocket
		ln -sf ../init.d/rc.rocket /etc/rc.d/rc0.d/K18rc.rocket
		ln -sf ../init.d/rc.rocket /etc/rc.d/rc1.d/K18rc.rocket
		ln -sf ../init.d/rc.rocket /etc/rc.d/rc6.d/K18rc.rocket
	fi

	if [ -f /etc/rc.d/rc.rocket ]; then
		echo "You have an old /etc/rc.d/rc.rocket script"
		echo "After checking to make sure it is no longer being used"
		echo "you should delete it."
	fi
else
	if [ ! -f /etc/rc.d/rc.rocket ]; then
		echo "The initialization script has been installed in "
		echo "/etc/rc.d/rc.rocket.  You will need to edit your "
		echo "/etc/rc files to run /etc/rc.d/rc.rocket"

		if [ ! -d /etc/rc.d ]; then 
			mkdir -p /etc/rc.d
		fi

		cp rc.rocket /etc/rc.d
	fi
fi

#
# Copy in the rocketport.conf file, if isn't already installed
#
if [ ! -f /etc/rocketport.conf ]; then
	cp rocketport.conf /etc
	echo "Make sure you check and edit the /etc/rocketport.conf file!"
fi

#
# Install the setrocket program
#
cp setrocket /bin/setrocket
strip /bin/setrocket
chmod 755 /bin/setrocket

